@@ -3,7 +3,7 @@ package Assert::Refute;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -32,7 +32,7 @@ The following code will issue a warning if required conditions are not met:
     # Big and hard to test chunk of code here
     # .......
 
-    refute_these {
+    try_refute {
         like $foo, qr/f?o?r?m?a?t/, "Format as expected";
         can_ok $bar, qw( do_this do_that frobnicate ),
             "Duck-typing an object";
@@ -40,14 +40,14 @@ The following code will issue a warning if required conditions are not met:
     };
 
 As the chunk-of-code is being rewritten into a proper function,
-the C<refute_these> block may serve as both a safety net
+the L</try_refute> block may serve as both a safety net
 and a prototype of a future unit test.
 
 The same may be written without polluting the calling package's namespace:
 
     use Assert::Refute;
 
-    my $report = refute_these {
+    my $report = try_refute {
         my $report = shift;
         $report->is( $foo, 42, "Meaning of life" );
         $report->like( $bar, qr/f?o?r?m?a?t?/, "Text as expected" );
@@ -65,14 +65,14 @@ can be fine-tuned, as in:
     };
 
 See L</EXPORT> and L</configure> below.
-See also L<Assert::Refute::Exec> for the underlying object-oriented interface.
+See also L<Assert::Refute::Report> for the underlying object-oriented interface.
 
 =head1 EXPORT
 
 Per-package configuration parameters can be passed as hash refs in
 use statement. Anything that is I<not> hash is passed to L<Exporter> module:
 
-    use Assert::Refute { on_fail => 'croak' }, "refute_these";
+    use Assert::Refute { on_fail => 'croak' }, "try_refute";
 
 Or more generally
 (this actually dies because C<foo> and C<bar> parameters are not expected):
@@ -89,7 +89,7 @@ The default is skip, i.e. do nothing.
 =item * on_fail => skip|carp|croak - what to do when conditions are I<not> met.
 The default is carp (issue a warning and continue on, even with wrong data).
 
-=item * driver => class - specify an L<Assert::Refute::Exec> subclass
+=item * driver => class - specify an L<Assert::Refute::Report> subclass
 to actually execute the tests, if you need to.
 
 =back
@@ -147,7 +147,7 @@ my @basic = (
     @Assert::Refute::T::Basic::EXPORT,
 );
 my @core  = qw(
-    contract refute_these
+    contract refute_these try_refute
     refute subcontract contract_is current_contract
 );
 
@@ -200,12 +200,12 @@ my %default_conf = (
     on_pass => 'skip',
 );
 
-=head2 refute_these { ... }
+=head2 try_refute { ... }
 
 Refute several conditions, warn or die if they fail,
 as requested during C<use> of this module.
 The coderef shall accept one argument, the contract execution object
-(likely a L<Assert::Refute::Exec>, see C<need_object> above).
+(likely a L<Assert::Refute::Report>, see C<need_object> above).
 
 More arguments MAY be added in the future.
 Return value is ignored.
@@ -213,19 +213,21 @@ A contract report object is returned instead.
 
 This is basically what one expects from a module in C<Assert::*> namespace.
 
-B<[EXPERIMENTAL]> This name is preliminary and is likely to change
-in the nearest future.
-It will stay available (with a warning) for at least 5 releases after that.
+=head2 refute_these
+
+B<[DEPRECATED]> Same as above.
+
+It will stay available (with a warning) until as least 0.15.
 
 =cut
 
-sub refute_these(&;@) { ## no critic # need prototype
+sub try_refute(&;@) { ## no critic # need prototype
     my ( $block, @arg ) = @_;
 
     # Should a missing config even happen? Ok, play defensively...
     my $conf = $CALLER_CONF{+caller};
     if( !$conf ) {
-        carp "refute_these(): Usage without explicit configure() is DEPRECATED, assuming { on_fail => 'carp' }";
+        carp "try_refute(): Usage without explicit configure() is DEPRECATED, assuming { on_fail => 'carp' }";
         $conf = __PACKAGE__->configure( { on_fail => 'carp' }, scalar caller );
     };
 
@@ -239,6 +241,11 @@ sub refute_these(&;@) { ## no critic # need prototype
     return $report;
 };
 
+sub refute_these (&;@) { ## no critic # need prototype
+    carp "refute_these { ... } is DEPRECATED, use try_refute{ ... } instead";
+    goto \&try_refute; ## no critic
+}
+
 =head2 refute( $condition, $message )
 
 Test one condition in scope of the current contract.
@@ -292,7 +299,7 @@ Note that contract does B<not> validate anything by itself,
 it just creates a read-only L<Assert::Refute::Contract>
 object sitting there and waiting for an C<apply> call.
 
-The C<apply> call returns a L<Assert::Refute::Exec> object containing
+The C<apply> call returns a L<Assert::Refute::Report> object containing
 results of specific execution.
 
 This is much like C<prepare> / C<execute> works in L<DBI>.
@@ -317,7 +324,7 @@ B<[NOTE]> that the message comes first, unlike in C<refute> or other
 test conditions, and is I<required>.
 
 A I<contract> may be an L<Assert::Refute::Contract> object
-or just a subroutine accepting an L<Assert::Refute::Exec> as first argument.
+or just a subroutine accepting an L<Assert::Refute::Report> as first argument.
 
 For instance, one could apply a previously defined validation to a
 structure member:
@@ -359,7 +366,7 @@ sub subcontract($$@) { ## no critic
 
 =head2 current_contract
 
-Returns the L<Assert::Refute::Exec> object being worked on.
+Returns the L<Assert::Refute::Report> object being worked on.
 Dies if no contract is being executed at the time.
 
 This is actually a clone of L<Assert::Refute::Build/current_contract>.
@@ -379,7 +386,7 @@ Set per-caller package configuration values for given package.
 C<configure> is called implicitly by C<use Assert::Refute { ... }>
 if hash parameter(s) are present.
 
-These are adhered to by L</refute_these>, mostly.
+These are adhered to by L</try_refute>, mostly.
 
 Available %options include:
 
@@ -390,13 +397,13 @@ Available %options include:
 =item * on_fail - callback to execute if tests fail (default: C<carp>,
 but not just C<Carp::carp> - see below).
 
-=item * driver - use that class instead of L<Assert::Refute::Exec>
+=item * driver - use that class instead of L<Assert::Refute::Report>
 as execution report.
 
 =back
 
 The callbacks MUST be either
-a C<CODEREF> accepting L<Assert::Refute::Exec> object,
+a C<CODEREF> accepting L<Assert::Refute::Report> object,
 or one of predefined strings:
 
 =over
@@ -438,10 +445,10 @@ sub configure {
         my $mod = "$conf->{driver}.pm";
         $mod =~ s#::#/#g;
         require $mod;
-        croak "$conf->{driver} is not Assert::Refute::Exec, cannot use as driver"
-            unless $conf->{driver}->isa('Assert::Refute::Exec');
+        croak "$conf->{driver} is not Assert::Refute::Report, cannot use as driver"
+            unless $conf->{driver}->isa('Assert::Refute::Report');
     } else {
-        $conf->{driver} = 'Assert::Refute::Exec'; # this works for sure
+        $conf->{driver} = 'Assert::Refute::Report'; # this works for sure
     };
 
     $CALLER_CONF{$caller} = $conf;
@@ -477,9 +484,9 @@ specialized tool exists for doing that.
 
 Use L<Assert::Refute::Build> to define new I<checks> as
 both prototyped exportable functions and their counterpart methods
-in L<Assert::Refute::Exec>.
+in L<Assert::Refute::Report>.
 These functions will perform absolutely the same
-under control of C<refute_these>, C<contract>, and L<Test::More>:
+under control of C<try_refute>, C<contract>, and L<Test::More>:
 
     package My::Prime;
 
@@ -508,7 +515,7 @@ and doesn't do anything except returning a value - it's a I<pure function>.
 
 Yet the exact reason for $n not being a prime will be reflected in test output.
 
-One can also subclass L<Assert::Refute::Exec>
+One can also subclass L<Assert::Refute::Report>
 to create new I<drivers>, for instance,
 to register failed/passed tests in a unit-testing framework of choice
 or generate warnings/exceptions when conditions are not met.
@@ -579,9 +586,16 @@ L<http://search.cpan.org/dist/Assert-Refute/>
 
 =head1 ACKNOWLEDGEMENTS
 
+=over
+
+=item Thanks to L<Alexander Kuklev|https://github.com/akuklev>
+for C<try_refute> function name as well as many useful discussions.
+
+=back
+
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017 Konstantin S. Uvarin. C<< <khedin at gmail.com> >>
+Copyright 2017-2018 Konstantin S. Uvarin. C<< <khedin at cpan.org> >>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
