@@ -3,7 +3,7 @@ package Assert::Refute::Driver::More;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -38,14 +38,14 @@ B<if> Test::More has been loaded B<before> Assert::Refute.
 
 =head1 METHODS
 
-We override some methods of L<Assert::Refute::Exec> below so that
+We override some methods of L<Assert::Refute::Report> below so that
 test results are fed to the more backend.
 
 =cut
 
 use Carp;
 
-use parent qw(Assert::Refute::Exec);
+use parent qw(Assert::Refute::Report);
 
 =head2 new
 
@@ -126,9 +126,9 @@ Indentation is ignored.
 sub do_log {
     my ($self, $indent, $level, @mess) = @_;
 
-    if ($level == 1) {
+    if ($level == -1) {
         $self->{builder}->diag($_) for @mess;
-    } elsif ($level > 1) {
+    } elsif ($level > 0) {
         $self->{builder}->note($_) for @mess;
     };
 
@@ -183,7 +183,7 @@ sub get_result {
 
 This module is part of L<Assert::Refute> suite.
 
-Copyright 2017 Konstantin S. Uvarin. C<< <khedin at gmail.com> >>
+Copyright 2017-2018 Konstantin S. Uvarin. C<< <khedin at cpan.org> >>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
