@@ -2,7 +2,7 @@ package Assert::Refute::T::Numeric;
 
 use strict;
 use warnings;
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -29,12 +29,12 @@ Same for production code:
     use Assert::Refute::T::Numeric;
 
     my $rotate = My::Rotation::Matrix->new( ... );
-    refute_these {
+    try_refute {
         within_delta $rotate->determinant, 1, 1e-6, "Rotation keeps distance";
     };
 
     my $total = calculate_price();
-    refute_these {
+    try_refute {
         is_between $total, 1, 100, "Price within reasonable limits";
     };
 
@@ -110,7 +110,7 @@ L<Test::Number::Delta>.
 
 This module is part of L<Assert::Refute> suite.
 
-Copyright 2017 Konstantin S. Uvarin. C<< <khedin at gmail.com> >>
+Copyright 2017-2018 Konstantin S. Uvarin. C<< <khedin at cpan.org> >>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
